<template>
  <el-dialog
    title="采集值"
    :close-on-click-modal="false"
    width="50%"
    v-model="visible"
  >
    <el-form
      :inline="true"
      :model="dataForm"
      @keydown.enter="getDataList()"
    >
      <el-form-item>
        <el-date-picker
          v-model="dataForm.startTime"
          type="datetime"
          value-format="yyyy-MM-dd HH:mm:ss"
          placeholder="选择日期时间"
       />
      </el-form-item>
      <el-form-item>
        <el-date-picker
          v-model="dataForm.endTime"
          type="datetime"
          value-format="yyyy-MM-dd HH:mm:ss"
          placeholder="选择日期时间"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="getDataList()">查询</el-button>
      </el-form-item>
      <el-form-item>
        <el-button
          type="success"
          plain
          @click="handleExport"
          :loading="exportLoading"
          v-hasPermi="['data:point:export']"
        >
          <Icon icon="ep:download" />导出
        </el-button>
      </el-form-item>
    </el-form>
    <div ref="chartDom" class="result-chart"></div>
  </el-dialog>
</template>

<script lang="ts" setup>
  import {ref} from 'vue';
  import * as echarts from 'echarts';
  import * as DaPoint from '@/api/data/da/point/daPointChart'
  import download from "@/utils/download";
  const message = useMessage() // 消息弹窗
  const visible = ref(false);
  const chartDom = ref(null);
  let myChart = null;
  const dataForm = ref({
    id: "",
    pointNo: "",
    pointName: "",
    pointTypeName: "",
    startTime: getYMDHMS(),
    endTime: undefined,
  });
  const queryParams = reactive({
    pointNo: "",
    start: undefined,
    end: undefined,
  })
  function getYMDHMS() {
    let timestamp = new Date().getTime();
    let time = new Date(timestamp - 1000 * 60 * 30);
    let year = time.getFullYear();
    let month = (time.getMonth() + 1).toString();
    let date = time.getDate().toString();
    let hours = time.getHours().toString();
    let minute = time.getMinutes().toString();

    if (month < 10) {
      month = "0" + month;
    }
    if (date < 10) {
      date = "0" + date;
    }
    if (hours < 10) {
      hours = "0" + hours;
    }
    if (minute < 10) {
      minute = "0" + minute;
    }
    return (
      year +
      "-" +
      month +
      "-" +
      date +
      " " +
      hours +
      ":" +
      minute +
      ":" +
      "00"
    );
  }
  /** 打开弹窗 */
  const open = async (row: object) => {
    visible.value = true
    dataForm.value.id = row.id;
    dataForm.value.pointNo = row.pointNo;
    dataForm.value.pointName = row.pointName;
    dataForm.value.startTime = getYMDHMS();
    dataForm.value.endTime = "";
    getDataList();
  }

  defineExpose({open}) // 提供 open 方法，用于打开弹窗

  async function getDataList() {
    visible.value = true;
    if (dataForm.value.id) {
      try {
        queryParams.pointNo=dataForm.value.pointNo;
        queryParams.start = dataForm.value.startTime;
        queryParams.end = dataForm.value.endTime;
        const data = await DaPoint.getPointDaChart(queryParams)
        const dataList = [];
        const xAxisData = [];
        data[dataForm.value.pointNo].forEach(function (value) {
          // 判断数据是否为布尔型
          if (typeof value["value"] === "boolean") {
            value["value"] = value["value"]? 1 : 0;
          }
          dataList.push([value["time"], value["value"]]);
          xAxisData.push(value["time"]);
        });
        let seriesData = [];
        seriesData.push({
          name: "采集值",
          type: "line",
          data: dataList,
          showSymbol: false,
          smooth: false,
          lineStyle: {
            normal: {
              color: "#5B8FF9",
              width: 1,
            },
          },
        });
        myChart = echarts.init(chartDom.value);
        const option = {
          title: {
            text: dataForm.value.pointName,
            top: 0,
            left: "1%",
            textStyle: {
              fontSize: 14,
            },
          },
          tooltip: {
            trigger: "axis",
            axisPointer: {
              type: "line",
              lineStyle: {
                color: "#cccccc",
                width: "1",
                type: "dashed",
              },
            },
          },
          legend: {
            show: false,
            top: 10,
          },
          grid: {
            top: 30,
            left: "3%",
            right: "5%",
            bottom: 10,
            containLabel: true,
          },
          xAxis: {
            type: "category",
            boundaryGap: false,
            data: xAxisData,
          },
          yAxis: {
            type: "value",
          },
          dataZoom: [
            {
              type: "inside",
            },
          ],
          series: seriesData,
        };
        myChart.clear();
        myChart.setOption(option);
      } catch (error) {
        console.error(error)
      }
    }
  }
  /** 导出按钮操作 */
  const exportLoading = ref(false)
  const handleExport = async () => {
    queryParams.pointNos=[dataForm.value.pointNo];
    queryParams.start = dataForm.value.startTime;
    queryParams.end = dataForm.value.endTime;
    try {
      // 导出的二次确认
      await message.exportConfirm()
      // 发起导出
      exportLoading.value = true
      const data = await DaPoint.exportDaPointValue(queryParams)
      download.excel(data, dataForm.value.pointName +'.xls')
    } catch {
    } finally {
      exportLoading.value = false
    }
  }
</script>
<style>
  .el-select {
    width: 100%;
  }

  .result-chart {
    height: 500px;
  }
</style>
